pub enum Value {
Show 16 variants Bang(String), Call(StringCallArgs), Function(StringOption<Function>), Literal(CssString), List(Vec<Value>, Option<ListSeparator>, bool), Numeric(Numericbool), Color(ColorOption<String>), Null, True, False, BinOp(Box<Value>, boolOperatorboolBox<Value>), UnaryOp(OperatorBox<Value>), Map(ValueMap), UnicodeRange(String), Paren(Box<Value>), ArgList(CallArgs),
}
A css value.

Variants

Bang(String)

A special kind of escape. Only really used for !important.

Call(StringCallArgs)

An function call that was not evaluated.

Function(StringOption<Function>)

A (callable?) function.

Literal(CssString)

A string literal.

List(Vec<Value>, Option<ListSeparator>, bool)

A comma- or space separated list of values, with or without brackets.

Numeric(Numericbool)

A Numeric value is a rational value with a Unit (which may be Unit::None) and flags.

The boolean flag is true for calculated values and false for literal values.

Color(ColorOption<String>)

A color value (and optionally, its source string).

Null

The null value.

True

The true boolean value.

False

The false boolean value.

BinOp(Box<Value>, boolOperatorboolBox<Value>)

A binary operation, two operands and an operator. The booleans represents possible whitespace.

UnaryOp(OperatorBox<Value>)

A unary operator and its operand.

Map(ValueMap)

A map of values.

UnicodeRange(String)

A unicode range for font selections. U+NN, U+N?, U+NN-MM. The string is the entire value, including the “U+” tag.

Paren(Box<Value>)

A value in parenthesis.

ArgList(CallArgs)

An argumentt list

Implementations

Create a numeric value with no unit.

Get the type name of this value.

Return true if this is a calculated value.

The return of functions or operators are calculated, verbatim values are not.

Get this value, but marked as calculated.

Make sure arithmetic operators are evaluated.

All values other than False and Null should be considered true.

Return true if this value is null.

Note that an empty unquoted string and a list containing no non-null values is also considered null.

Check if this value is numeric.

If it is, get the number and unit, otherwise, get the value itself as error.

Unquote this value.

If the value is a quoted string, the content is unquoted.

Get this value as iterable items.

Lists and maps have iterable items, which are returned as a vector of values. Other values are returned as a vec containing the value as a single item.

Get a reference to this Value bound to an output format.

The bound referene implements Display, so it can be written with the rust format!(...) macros or coverted with the to_string()` method.

Example
assert_eq!(
    Value::scalar(42).format(Default::default()).to_string(),
    "42",
);