pub enum SelectorPart {
Simple(SassString),
Descendant,
RelOp(u8),
Attribute {
name: SassString,
op: String,
val: SassString,
modifier: Option<char>,
},
PseudoElement {
name: SassString,
arg: Option<Selectors>,
},
Pseudo {
name: SassString,
arg: Option<Selectors>,
},
BackRef,
}Expand description
A selector consist of a sequence of these parts.
Variants
Simple(SassString)
A simple selector, eg a class, id or element name.
Note that a Simple selector can hide a more complex selector through string interpolation.
Descendant
The empty relational operator.
The thing after this is a descendant of the thing before this.
RelOp(u8)
A relational operator; >, +, ~.
Attribute
An attribute selector
PseudoElement
A css3 pseudo-element (::foo)
Fields

name: SassStringThe name of the pseudo-element
Pseudo
A pseudo-class or a css2 pseudo-element (:foo)
Fields

name: SassStringThe name of the pseudo-class
BackRef
A sass backref (&), to be replaced with outer selector.