pub enum Operator {
Show 15 variants
And,
Or,
Equal,
EqualSingle,
NotEqual,
Greater,
GreaterE,
Lesser,
LesserE,
Plus,
Minus,
Multiply,
Div,
Modulo,
Not,
}Expand description
An operator that can be used in a sass value.
Variants
And
The boolean (value propagating) and operator.
Or
The boolean (value propagating) or operator.
Equal
The == operator.
EqualSingle
The = operator. Used insted of Equal in media queries.
NotEqual
The != operator.
Greater
The > operator.
GreaterE
The >= operator.
Lesser
The < operator.
LesserE
The <= operator.
Plus
The + operator. Also unary positive.
Minus
The - operator. Also unary negative.
Multiply
The * operator.
Div
The / operator.
Modulo
The % operator.
Not
The unary not operator.
Implementations
Sourceimpl Operator
impl Operator
Sourcepub fn eval(&self, a: Value, b: Value) -> Result<Option<Value>, BadOp>
pub fn eval(&self, a: Value, b: Value) -> Result<Option<Value>, BadOp>
Evaluate this operator with two operands.
Some operations are known to be invalid, and for those an
error is returned.
Other operations cannot be evaluated but may be valid as is
e.g. in a calc(...) value. In that case, eval returns
Ok(None).